======================
django-sendgrid-events
======================

a simple app to provide and endpoind for and handle batch events from
SendGrid's Event API

Documentation is online at http://django-sendgrid-events.rtfd.org
